<?php include_once('admin/settings.php');?>
<!doctype html>
<head>
 <?php 
	$judet = $_GET['judet'];
	$id = $_GET['id'];
	if($id != null){
		$sql = mysql_query("SELECT * FROM `locatie_cazare` where id = '".$id."'");
			while($rand = mysql_fetch_row($sql)){
if ($rand['10'] == null){
		if ($rand['9'] == null){$loc1 = $rand['8'];}else{$loc1 = $rand['9'];}	
			}else{$loc1 = $rand['10'];}
$loc = str_ireplace($ptr_url, '-', $loc1);	
$loc2 = $loc1;
$keyword = str_ireplace($ptr_keyword, ', ', strtolower($rand['6']));

echo'<title>Cazare, '.ucwords(strtolower($rand['6'])).', '.date(Y).', '.ucwords(strtolower($rand['5'])).', '.ucwords(strtolower($loc1)).', '.ucwords(strtolower($rand['7'])).', Romania, Telefon, Poze</title>
	<meta name="Keywords" content="Cazare, '.ucwords(strtolower($rand['6'])).', '.date(Y).', '.ucwords(strtolower($rand['5'])).', '.ucwords(strtolower($loc1)).', '.ucwords(strtolower($rand['7'])).', Romania, Telefon, Poze" />
	<meta name="Description" content="Cazare, '.ucwords(strtolower($rand['6'])).', '.date(Y).', '.ucwords(strtolower($rand['5'])).', '.ucwords(strtolower($loc1)).', '.ucwords(strtolower($rand['7'])).', Romania, Telefon, Poze"  />';
	}
}else{
echo'<title>Cazare, '.ucwords($judet).','.$hotel.' cazare munte, cazare litoral, cazare moeciu, cazare azuga, cazare vatra dornei, cazare voineasa, cazare 2 mai, cazare straja</title>
	<meta name="Keywords" content="Cazare, '.ucwords($judet).','.$hotel.' cazare munte, cazare litoral, cazare moeciu, cazare azuga, cazare vatra dornei, cazare voineasa, cazare 2 mai, cazare straja" />
	<meta name="Description" content="Cazare, '.ucwords($judet).','.$hotel.' cazare munte, cazare litoral, cazare moeciu, cazare azuga, cazare vatra dornei, cazare voineasa, cazare 2 mai, cazare straja" />';
}
?> 
	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
	<meta http-equiv="Content-Language" content="ro">
	<meta name="Generator" content="Notepad++" />
	<meta name="Author" content="moshulescu - stefanfloringr@gmail.com" />
	<meta name = "revisit-after" content = "1 day" /> 
	<meta name = "document-rating" content = "General" />
	<meta name="robots" content="index,follow" />
	<link rel="shortcut icon" href="favicon.ico" >
    <link rel="icon" type="image/gif" href="ro-cazare-favicon.gif" >
		<!--[if IE]><script src="http://html5shiv.googlecode.com/svn/trunk/html5.js"></script><![endif]-->
	<link rel="stylesheet" href="http://www.romania-cazare.info/rezerva-cazare/romania-cazare.css"  type="text/css" media="screen" />
	<link href='http://fonts.googleapis.com/css?family=Rye' rel='stylesheet' type='text/css' />
	<link href='http://fonts.googleapis.com/css?family=Questrial' rel='stylesheet' type='text/css'>
	<meta name="google-site-verification" content="T_1-OVwJq8lBb5YkQ_M7JB4xmWuOJFONMR8EiJ6w1XM" />
</head>
<body>
<div id="fb-root"></div>
<script>(function(d, s, id) {
  var js, fjs = d.getElementsByTagName(s)[0];
  if (d.getElementById(id)) return;
  js = d.createElement(s); js.id = id;
  js.src = "//connect.facebook.net/ro_RO/all.js#xfbml=1";
  fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>

<table width="1000px" align="center" cellpadding="0" cellspacing="0">
	<tr>
		<td id="header" colspan="3">
			<a href="<?php $_SERVER['SCRIPT_NAME'] ?>/rezerva-cazare/" title="Portal de promovare turistica pentru locatii de cazare din Romania" alt="Portal de promovare turistica pentru locatii de cazare din Romania">
				<img style="float: right; margin: 25px;" src="http://www.ro-cazare.info/upload/foto_mica/promovare-turistica-gratuit-ro-cazare-138x138.jpg">
			</a>
			<p style="margin-left: 24px; ">
			Portal de promovare turistica<br />pentru locatii de cazare din Romania
			</p>
			<p style="width: 99%; font-family : 'Questrial', sans-serif; font-size : 12px; font-weight : 400; text-align: center;">
			Cazare Munte, Cazare Busteni, Cazare Predeal, Cazare Sibiu, Cazare Moeciu, Cazare Azuga, Cazare Vatra Dornei, Cazare Voineasa, Cazare Straja
			</p>	
		</td>
	</tr>
	<tr>
		<td height="4px" colspan="3">
			
		</td>
	</tr>
	<tr>
		<td id="cautare____" colspan="3">
	<div id="menuorizontal">
<a href="http://www.ro-cazare.info/contact.html"><p id="butonmenuoriz">Contact</p></a>
<a href="http://www.ro-cazare.info/inscrie-locatie.html"><p id="butonmenuoriz">Adauga cazare</p></a>
<a href="index.php"><p id="butonmenuoriz">Acasa</p></a>
	</div>
			<form method="post" action="index.php">
<fieldset id="fieldsetcautare">
		<legend id="legendcautare" align="left">Alege criterii cautare</legend>
			<select id="selectcautare" name="judet" class="camp" title="Obligatoriu" alt="Obligatoriu">
				<option value="">Alege judet cazare</option>
				<option value="Alba">Alba</option>
				<option value="Arad">Arad</option>
				<option value="Arges">Arges</option>
				<option value="Bacau">Bacau</option>
				<option value="Bihor">Bihor</option>
				<option value="Bistrita Nasaud">Bistrita Nasaud</option>
				<option value="Botosani">Botosani</option>
				<option value="Brasov">Brasov</option>
				<option value="Braila">Braila</option>
				<option value="Bucuresti">Bucuresti</option>
				<option value="Buzau">Buzau</option>
				<option value="Caras Severin">Caras Severin</option>
				<option value="Calarasi">Calarasi</option>
				<option value="Cluj">Cluj</option>
				<option value="Constanta">Constanta</option>
				<option value="Covasna">Covasna</option>
				<option value="Dambovita">Dambovita</option>
				<option value="Dolj">Dolj</option>
				<option value="Galati">Galati</option>
				<option value="Giurgiu">Giurgiu</option>
				<option value="Gorj">Gorj</option>
				<option value="Harghita">Harghita</option>
				<option value="Hunedoara">Hunedoara</option>
				<option value="Ialomita">Ialomita</option>
				<option value="Iasi">Iasi</option>
				<option value="Ilfov">Ilfov</option>
				<option value="Maramures">Maramures</option>
				<option value="Mehedinti">Mehedinti</option>
				<option value="Mures">Mures</option>
				<option value="Neamt">Neamt</option>
				<option value="Olt">Olt</option>
				<option value="Prahova">Prahova</option>
				<option value="Satu Mare">Satu Mare</option>
				<option value="Salaj">Salaj</option>
				<option value="Sibiu">Sibiu</option>
				<option value="Suceava">Suceava</option>
				<option value="Teleorman">Teleorman</option>
				<option value="Timis">Timis</option>
				<option value="Tulcea">Tulcea</option>
				<option value="Vaslui">Vaslui</option>
				<option value="Valcea">Valcea</option>
				<option value="Vrancea">Vrancea</option>
			</select>
			<select id="selectcautare" name="tip_locatie">
				<option value="" selected>Alege tip cazare</option>
				<option value="Hotel">Hotel</option>
				<option value="Pensiune" >Pensiune</option>
				<option value="Vila" >Vila</option>
				<option value="Complex" >Complex</option>
				<option value="Motel" >Motel</option>
				<option value="Apartament" >Apartament</option>
				<option value="Garsoniera" >Garsoniera</option>
				<option value="Hostel">Hostel</option>
			</select>
			<select id="selectcautare" name="clasificare">
				<option value="" selected>Alege clasificare cazare</option>
				<option value="1 stea" >1 stea</option>
				<option value="2 stele" >2 stele</option>
				<option value="2+ stele" >2 stele+</option>
				<option value="3 stele" >3 stele</option>
				<option value="3+ stele" >3 stele+</option>
				<option value="4 stele" >4 stele</option>
				<option value="4+ stele" >4 stele+</option>
				<option value="5 stele" >5 stele</option>
			</select>
		<input id="selectcautare" name="denumire" type="text" value="" />
		<input id="cauta" name="submit_cautare" type="submit" value="Cauta locatie" title="" alt="" />
			<br />
			<br />
	</fieldset>
</form>
		</td>
	</tr>
	<tr>
		<td id="spatiuorizontal" colspan="3">
			
		</td>
	</tr>
	<tr>
		<td id="dinamic">
			 <?php include('dinamic.php'); ?>
		</td>
		<td width="10px" valign="middle">
			
		</td>
		<td id="coloanadreapta">
			<?php include('dreapta.php'); ?>
		</td>
	</tr>
	<tr>
		<td id="spatiuorizontal" colspan="3">
			
		</td>
	</tr>
	<tr>
		<td id="footer" colspan="3">
			<?php include('footer.php'); ?>
		</td>
	</tr>
</table>

</body>
</html>