<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
  <meta content="text/html; charset=ISO-8859-1" http-equiv="content-type">
  <title>www.romania-cazare.info</title>
</head>
<body>
<div style="text-align: center;"><br>
<br>
<br>
<big style="font-weight: bold; font-family: Courier New;"><big><big>www.romania-cazare.info</big></big></big><br>
<img style="width: 303px; height: 303px;" alt="Site in Constructie" src="http://www.constantapetshop.ro/computer.jpg" align="middle"><br>
<big style="font-weight: bold; font-family: Courier New;"><big><big>Mentenanta<br>
Va rugam sa reveniti<br>
Multumim<br>
</big></big></big></div>
</body>
</html>
