<?php 
echo'<form method="post" action="index.php">';
echo'<fieldset id="fieldsetcautare">
		<legend id="legendcautare" align="left">Alege criterii cautare</legend>
				<br />
			<select id="selectcautare" name="judet" title="Obligatoriu" alt="Obligatoriu">
				<option value="">Alege judet cazare</option>
				<option value="Alba">Alba</option>
				<option value="Arad">Arad</option>
				<option value="Arges">Arges</option>
				<option value="Bacau">Bacau</option>
				<option value="Bihor">Bihor</option>
				<option value="Bistrita Nasaud">Bistrita Nasaud</option>
				<option value="Botosani">Botosani</option>
				<option value="Brasov">Brasov</option>
				<option value="Braila">Braila</option>
				<option value="Bucuresti">Bucuresti</option>
				<option value="Buzau">Buzau</option>
				<option value="Caras Severin">Caras Severin</option>
				<option value="Calarasi">Calarasi</option>
				<option value="Cluj">Cluj</option>
				<option value="Constanta">Constanta</option>
				<option value="Covasna">Covasna</option>
				<option value="Dambovita">Dambovita</option>
				<option value="Dolj">Dolj</option>
				<option value="Galati">Galati</option>
				<option value="Giurgiu">Giurgiu</option>
				<option value="Gorj">Gorj</option>
				<option value="Harghita">Harghita</option>
				<option value="Hunedoara">Hunedoara</option>
				<option value="Ialomita">Ialomita</option>
				<option value="Iasi">Iasi</option>
				<option value="Ilfov">Ilfov</option>
				<option value="Maramures">Maramures</option>
				<option value="Mehedinti">Mehedinti</option>
				<option value="Mures">Mures</option>
				<option value="Neamt">Neamt</option>
				<option value="Olt">Olt</option>
				<option value="Prahova">Prahova</option>
				<option value="Satu Mare">Satu Mare</option>
				<option value="Salaj">Salaj</option>
				<option value="Sibiu">Sibiu</option>
				<option value="Suceava">Suceava</option>
				<option value="Teleorman">Teleorman</option>
				<option value="Timis">Timis</option>
				<option value="Tulcea">Tulcea</option>
				<option value="Vaslui">Vaslui</option>
				<option value="Valcea">Valcea</option>
				<option value="Vrancea">Vrancea</option>
			</select>
			<select id="selectcautare" name="tip_locatie">
				<option value="" selected>Alege tip cazare</option>
				<option value="Hotel">Hotel</option>
				<option value="Pensiune" >Pensiune</option>
				<option value="Vila" >Vila</option>
				<option value="Complex" >Complex</option>
				<option value="Motel" >Motel</option>
				<option value="Apartament" >Apartament</option>
				<option value="Garsoniera" >Garsoniera</option>
				<option value="Hostel">Hostel</option>
			</select>
			<select id="selectcautare" name="clasificare">
				<option value="" selected>Alege clasificare cazare</option>
				<option value="1 stea" >1 stea</option>
				<option value="2 stele" >2 stele</option>
				<option value="2+ stele" >2 stele+</option>
				<option value="3 stele" >3 stele</option>
				<option value="3+ stele" >3 stele+</option>
				<option value="4 stele" >4 stele</option>
				<option value="4+ stele" >4 stele+</option>
				<option value="5 stele" >5 stele</option>
			</select>
		<input id="cauta" name="submit_cautare" type="submit" value="Cauta locatie" title="" alt="" />
			<br />
			<br />
		* Toate criteriile sunt obligatirii 
	</fieldset>
</form>';
////////// end formular cautare /////////////////
?>