<?php //include('logat/autentificare.php');
///////////// start promo /////////////
$sql = mysql_query("SELECT 
	locatie_cazare.id,
	locatie_cazare.tip_locatie, 
	locatie_cazare.clasificare, 
	locatie_cazare.denumire_locatie, 
	locatie_cazare.judet, 
	locatie_cazare.oras, 
	locatie_cazare.comuna,
	locatie_cazare.sat, 	
	locatie_cazare.promovare,
	locatie_cazare.status,
	foto_locatie.foto_mica, 
	foto_locatie.id_locatie 
		from 
	locatie_cazare INNER JOIN foto_locatie ON 
	locatie_cazare.id = foto_locatie.id_locatie 
		WHERE 
	locatie_cazare.promovare = 'PLATIT' 
		and 
	locatie_cazare.status = 'ACTIV' order by RAND() LIMIT 1");
	
while($locatie = mysql_fetch_row($sql)){

if ($locatie['7'] == null){
		if ($locatie['6'] == null){$loc1 = $locatie['5'];}else{$loc1 = $locatie['6'];}	
			}else{$loc1 = $locatie['7'];}
$url_loc = str_ireplace($ptr_url, '-', $loc1);	
$url_denumire = str_ireplace($ptr_url, '-', $locatie['3']);	

echo'<a href="http://'.$title.'/rezerva-cazare/cazare-'.strtolower($locatie['1']).'-'.strtolower($locatie['4']).'-'.strtolower($url_loc).'-'.strtolower($url_denumire).'-'.$locatie['0'].'.html" alt="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['3'])).' - '.$title.'" title="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['3'])).' - '.$title.'" >
<center>
	<fieldset id="fieldsetdreaptapromo">
	 <legend id="legenddreapta" align="left">Promovat</legend>

<img id="fotopromo" src="http://www.ro-cazare.info/upload/foto_mica/'.$locatie['10'].'" title="Click si vezi detalii despre aceasta locatie de cazare - Portal de promovare turistica pentru locatii de cazare din Romania" alt="Click si vezi detalii despre aceasta locatie de cazare - Portal de promovare turistica pentru locatii de cazare din Romania" />
	<br />
<center><h3>'.ucwords(strtolower($locatie['3'])).'</h3></center>
'.ucwords(strtolower($locatie['1'])).' '.ucwords(strtolower($locatie['2'])).'<br />
'.ucwords(strtolower($locatie['4'])).' '.ucwords(strtolower($locatie['5'])).' '.ucwords(strtolower($locatie['6'])).'';
echo'<br />';
	$sql_tarife = mysql_query("SELECT * FROM `tarife_cazare` WHERE id_locatie = ".$locatie['0']."  order by pret desc limit 0,1");
		while($pret = mysql_fetch_row($sql_tarife)){	
$pret = $pret['7'];
echo'<p style="text-align: center; vertical-align: bottom; font-family : \'Rye\', cursive; font-size : 14px; color : #156CB9;">
		De la '.$pret.' Lei
	</p>';
		}
echo'</fieldset>
</center></a>';
}
///////////// end promo /////////////

//// start E-COMERT.INFO ////
echo'<a href="http://www.e-comert.info" target="_blank">
<center>
<fieldset id="fieldsetdreapta">
	 <legend id="legenddreapta" align="left">e-comert.info</legend>
	 <center>Este un website de marketing afiliat care doreste sa adune in acelasi loc majoritatea ofertelor, reducerilor si promotiilor ale celor mai mari retaileri din Romania</center>
<img style="width: 156px;" src="http://www.ro-cazare.info/img/solicita-oferta-cazare-174x174_2.png">	 
</fieldset>
</center>
</a>';
//// end E-COMERT.INFO ////

///////////// start evaluare /////////////
//if ($_GET['id'] != null){ include('../ro-cazare.info/evaluare.php');}
///////////// end evaluare /////////////

// ///////////// start ultimele inscrise /////////////
// $sql = mysql_query("SELECT * FROM `locatie_cazare` WHERE status = 'ACTIV' ORDER BY ultima_actualizare DESC limit 0,10");
// echo'<center>
	// <fieldset id="fieldsetdreapta">
	 // <legend id="legenddreapta" align="left">Actualizate</legend>';
// echo'<table style="width: 100%;">';
	// while($locatie = mysql_fetch_row($sql)){
	
// if ($locatie['10'] == null){
		// if ($locatie['9'] == null){$loc1 = $locatie['8'];}else{$loc1 = $locatie['9'];}	
			// }else{$loc1 = $locatie['10'];}
// $url_loc = str_ireplace($ptr_url, '-', $loc1);	
// $url_denumire = str_ireplace($ptr_url, '-', $locatie['6']);	

	// echo '<tr>
			// <td>'.++$nrcrt.'.</td>
			// <td>
// <a href="http://'.$title.'/rezerva-cazare/cazare-'.strtolower($locatie['4']).'-'.strtolower($locatie['7']).'-'.strtolower($url_loc).'-'.strtolower($url_denumire).'-'.$locatie['0'].'.html" alt="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['6'])).' - '.$title.'" title="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['6'])).' - '.$title.'">'.ucwords(strtolower($locatie['6'])).'</a>
			// </td>
		// </tr>';
	// }
// echo'</table>
	// </fieldset>
// </center>';
// ///////////// end ultimele inscrise /////////////

///////////// start ultimele vizitate /////////////
$sql = mysql_query("SELECT * FROM `locatie_cazare` WHERE status = 'ACTIV' ORDER BY ultima_vizita DESC limit 0,10");
echo'<center>
	<fieldset id="fieldsetdreapta">
	 <legend id="legenddreapta" align="left">Ultimele vizitate</legend>';
echo'<table style="width: 100%;">';
	while($locatie = mysql_fetch_row($sql)){
	
if ($locatie['10'] == null){
		if ($locatie['9'] == null){$loc1 = $locatie['8'];}else{$loc1 = $locatie['9'];}	
			}else{$loc1 = $locatie['10'];}
$url_loc = str_ireplace($ptr_url, '-', $loc1);	
$url_denumire = str_ireplace($ptr_url, '-', $locatie['6']);	

	echo '<tr>
			<td>'.++$nrcrt.'.</td>
			<td>
<a href="http://'.$title.'/rezerva-cazare/cazare-'.strtolower($locatie['4']).'-'.strtolower($locatie['7']).'-'.strtolower($url_loc).'-'.strtolower($url_denumire).'-'.$locatie['0'].'.html" alt="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['6'])).' - '.$title.'" title="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['6'])).' - '.$title.'">'.ucwords(strtolower($locatie['6'])).'</a>
			</td>
		</tr>';
	}
echo'</table>
	</fieldset>
</center>';
///////////// end ultimele vizitate /////////////

///////////// start ultimele comentarii /////////////
$sql = mysql_query("SELECT 
	locatie_cazare.id,
	locatie_cazare.tip_locatie, 
	locatie_cazare.clasificare, 
	locatie_cazare.denumire_locatie, 
	locatie_cazare.judet, 
	locatie_cazare.oras, 
	locatie_cazare.comuna,
	locatie_cazare.sat, 	
	locatie_cazare.promovare,
	locatie_cazare.status,
	comentarii.id,
	comentarii.id_locatie 	
		from 
	locatie_cazare INNER JOIN comentarii ON 
	locatie_cazare.id = comentarii.id_locatie 
		WHERE 
	comentarii.status = 'ACTIV' 
		and 
	locatie_cazare.status = 'ACTIV' order by comentarii.id desc LIMIT 0,10");
echo'
<center>
	<fieldset id="fieldsetdreapta">
	 <legend id="legenddreapta" align="left">Pareri, Impresii</legend>';
echo'<table width="100%">';
	while($locatie = mysql_fetch_row($sql)){
	
if ($locatie['7'] == null){
		if ($locatie['6'] == null){$loc1 = $locatie['5'];}else{$loc1 = $locatie['6'];}	
			}else{$loc1 = $locatie['7'];}
$url_loc = str_ireplace($ptr_url, '-', $loc1);	
$url_denumire = str_ireplace($ptr_url, '-', $locatie['3']);	
		
	echo '<tr>
			<td>'.++$nr.'.</td>
			<td>
<a href="http://'.$title.'/rezerva-cazare/cazare-'.strtolower($locatie['1']).'-'.strtolower($locatie['4']).'-'.strtolower($url_loc).'-'.strtolower($url_denumire).'-'.$locatie['0'].'.html#pareri" alt="Apasa pentru a vizualiza parerile si impresiile turistilor ce au vizitat - '.ucwords(strtolower($locatie['3'])).' - '.$title.'" title="Apasa pentru a vizualiza parerile si impresiile turistilor ce au vizitat - '.ucwords(strtolower($locatie['3'])).' - '.$title.'">'.ucwords(strtolower($locatie['3'])).'</a>
			</td>
		</tr>';
	}
echo'</table>
	</fieldset>
</center>';
///////////// end ultimele comentarii /////////////

///////////// start cele mai vizitate /////////////
$sql = mysql_query("SELECT * FROM `locatie_cazare` WHERE status = 'ACTIV' ORDER BY nr_vizualizari DESC limit 0,10");
echo'
<center>
	<fieldset id="fieldsetdreapta">
	 <legend id="legenddreapta" align="left">Cele mai vizitate</legend>';
echo'<table width="100%">';
	while($locatie = mysql_fetch_row($sql)){
	
if ($locatie['10'] == null){
		if ($locatie['9'] == null){$loc1 = $locatie['8'];}else{$loc1 = $locatie['9'];}	
			}else{$loc1 = $locatie['10'];}
$url_loc = str_ireplace($ptr_url, '-', $loc1);	
$url_denumire = str_ireplace($ptr_url, '-', $locatie['6']);	
		
	echo '<tr>
			<td>'.++$nr12.'.</td>
			<td>
<a href="http://'.$title.'/rezerva-cazare/cazare-'.strtolower($locatie['4']).'-'.strtolower($locatie['7']).'-'.strtolower($url_loc).'-'.strtolower($url_denumire).'-'.$locatie['0'].'.html" alt="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['6'])).' - '.$title.'" title="Apasa pentru a vizualiza locatia - '.ucwords(strtolower($locatie['6'])).' - '.$title.'">'.ucwords(strtolower($locatie['6'])).'</a>
			</td>
		</tr>';
	}
echo'</table>
	</fieldset>
</center>';
///////////// end cele mai vizitate /////////////
?>
<br />
<!-- BEGIN: Powered by Supercounters.com -->
<center><script type="text/javascript" src="http://widget.supercounters.com/online_i.js"></script><script type="text/javascript">sc_online_i(1152089,"ffffff","1e28e6");</script><br><noscript><a href="http://www.supercounters.com/">Free Online Counter</a></noscript>
</center>
<!-- END: Powered by Supercounters.com -->
