<?php

if ($_POST['submit'] and $_POST['conditie'] == '10'){

$id_locatie = stripslashes ( strip_tags ($_POST['id_locatie']));
$nume1 = stripslashes ( strip_tags ($_POST['nume']));
$nume = str_ireplace(array('"', "'", '/'), '', $nume1);

$email1 = stripslashes ( strip_tags ($_POST['email']));
$email = str_ireplace(array('"', "'", '/'), '', $email1);

$amabilitate = stripslashes ( strip_tags ($_POST['amabilitate']));
$personal = stripslashes ( strip_tags ($_POST['personal']));
$receptie = stripslashes ( strip_tags ($_POST['receptie']));
$confort = stripslashes ( strip_tags ($_POST['confort']));
$facilitati = stripslashes ( strip_tags ($_POST['facilitati']));
$servicii = stripslashes ( strip_tags ($_POST['servicii']));
$curatenie = stripslashes ( strip_tags ($_POST['curatenie']));
$locatie = stripslashes ( strip_tags ($_POST['locatie']));
$imprejurimi = stripslashes ( strip_tags ($_POST['imprejurimi']));
$calitate = stripslashes ( strip_tags ($_POST['calitate']));
$comentarii1 = stripslashes ( strip_tags ($_POST['comentarii']));
$comentarii = str_ireplace(array('"', "'", '/'), '', $comentarii1);

$email_coment = stripslashes ( strip_tags ($_POST['email_coment']));
$cod_securitate = stripslashes ( strip_tags ($_POST['cod_securitate']));

$media = (($amabilitate+$personal+$receptie+$confort+$facilitati+$servicii+$curatenie+$locatie+$imprejurimi+$calitate)/10);

if (($nume === 'nume (obligatoriu)') or ($nume === '')){
		
	echo "<script>alert('Nume necompletat ')</script>";
	echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";
}
if (($email === 'email (obligatoriu)') or ($email === '')){
		
	echo "<script>alert('Email necompletat ')</script>";
	echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";
}

if(eregi("@", $email)) {
if (($cod_securitate != '') and ($cod_securitate == '18')){

$status = 'ACTIV';
/////// start scrie comentariu si nota in db ///////////////////
$adauga_comentariu = mysql_query ("INSERT INTO `comentarii`(`id`, `data`, `ip`, `id_locatie`, `nume`, `email`, `amabilitate`, `personal`, `receptie`, `confort`, `facilitati`, `servicii`, `curatenie`, `locatie`, `imprejurimi`, `calitate`, `media`, `comentarii`, `email_coment`, `status`) VALUES ('', '".$data."', '".$_SERVER['REMOTE_ADDR']."', '".$id_locatie."', '".$nume."', '".$email."', '".$amabilitate."', '".$personal."', '".$receptie."', '".$confort."', '".$facilitati."', '".$servicii."', '".$curatenie."', '".$locatie."', '".$imprejurimi."', '".$calitate."', '".$media."', '".$comentarii."', '".$email_coment."', '".$status."');") or die(mysql_error());
/////// end scrie comentariu si nota in db ///////////////////

/////// start trimite email la proprietar pensiune ///////////////////
$sql_email_proprietar = mysql_query("SELECT * FROM `locatie_cazare` WHERE id = '".$id_locatie."'");
	while($email_proprietar = mysql_fetch_row($sql_email_proprietar)){	
		
		$to = $email_proprietar['19'];
		$subject = 'Comentariu nou pe '.$title;
		$headers = 'MIME-Version: 1.0'."\r\n";
		$headers .= 'Content-type: text/html; charset=iso-8859-1'."\r\n";
		$headers .= 'From: contact@ro-cazare.info'."\r\n";
	$content = 'Aceasta instiintare este trimisa automat de catre site '.$title.'.
		<br /><br />
			Primiti aceasta instiintare deoarece sunteti inscris in <b>Portalul de Promovare Turistica online <a href="http://'.$title.'" target="_blank">'.$title.'</a></b> si un vizitator care se afla chiar in acest moment pe pagina dedicata locatiei dumneavoastra de cazare a facut o apreciere si/sau un comentariu referitor la aceasta. 
		<br /><br />
	<a href="'.$_SERVER['HTTP_REFERER'].'" target="_blank">Apasati aici pentru a vedea aprecierile postate</a>
		<br /><br />
	Totul pentru sporirea numarului de oaspeti, turisti deci ... pentru prosperitatea afacerii dumneavoastra. 
		<br /><br />
		Va multumim pentru interesul acordat site-ului <a href="http://'.$title.'" target="_blank">'.$title.'</a>.';
	mail($to , $subject, $content, $headers );	
	}
/////// end trimite email la proprietar pensiune ///////////////////

/////// start trimite email la cei ce au comentat ///////////////////
$sql_email_comentator = mysql_query("SELECT * FROM `comentarii` WHERE id_locatie = '".$id_locatie."' and status = 'ACTIV' and email_coment = '1'");
	while($email_comentator = mysql_fetch_row($sql_email_comentator)){	
		
		$to = $email_comentator['5'];
		$subject = 'Comentariu nou pe '.$title;
		$headers = 'MIME-Version: 1.0'."\r\n";
		$headers .= 'Content-type: text/html; charset=iso-8859-1'."\r\n";
		$headers .= 'From: contact@ro-cazare.info'."\r\n";
	$content = 'Aceasta instiintare este trimisa automat de catre site '.$title.'.
		<br /><br />
			Primiti aceasta instiintare deoarece ati postat aprecieri si comentarii in <b>Portalul de Promovare Turistica online <a href="http://'.$title.'" target="_blank">'.$title.'</a></b> si ati ales sa fiti instiintat cand apar  aprecieri sau comentarii noi. 
		<br /><br />
	<a href="'.$_SERVER['HTTP_REFERER'].'" target="_blank">Apasati aici pentru a vedea aprecierile postate</a>
		<br /><br />
		Va multumim pentru interesul acordat site-ului <a href="http://'.$title.'" target="_blank">'.$title.'</a>.';
	mail($to , $subject, $content, $headers );	
	}
/////// end trimite email la cei ce au comentat ///////////////////

	}else{
		echo "<script>alert('Cod de securitate incorect ')</script>";
		echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";	
	}
	}else{
	echo "<script>alert('Email incorect ')</script>";
	echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";	
		}
	echo "<script>location.replace('".$_SERVER['HTTP_REFERER']."')</script>";	
}
?>


		