<?php
if(!isset($_GET['pagina'])) $_GET['pagina'] = '';
switch($_GET['pagina']) {
case '':
include "home.php";
break;
case 'inscrie-locatie':
include "inscrie_locatie.php";
break;
case 'verifica_form_adauga_partener':
include "verifica_form_adauga_partener.php";
break;
case 'proforma':
include "proforma.php";
break;
case 'autentificare':
include "autentificare.php";
break;
case 'inregistrare':
include "inregistrare.php";
break;
case 'cazare':
include "arata_cazare.php";
break;
case 'deconectare':
include "deconectare.php";
break;
case 'contact':
include "contact.php";
break;
case 'cautare':
include "cautare.php";
break;
case 'eroare':
include "eroare.php";
break;
case 'comentarii':
include "comentarii.php";
break;
case 'promovare-premium':
include "promovare-premium.php";
break;
case 'promotie-iunie-2013':
include "promotie.php";
break;
case 'test':
include "test.php";
break;
}
?>
