<!--<script type='text/javascript'>(function () { var done = false; var script = document.createElement('script'); script.async = true; script.type = 'text/javascript'; script.src = 'https://widget.purechat.com/VisitorWidget/WidgetScript'; document.getElementsByTagName('HEAD').item(0).appendChild(script); script.onreadystatechange = script.onload = function (e) { if (!done && (!this.readyState || this.readyState == 'loaded' || this.readyState == 'complete')) { var w = new PCWidget({ c: '78b588c6-4efd-4bba-bd55-a649fafe47a8', f: true }); done = true; } }; })();</script>-->
<?php
echo'
<p style="width:97%; padding: 12px; margin: 2px; text-align: center; background-color: #F9F9F9; border: solid thin #000000; -webkit-border-radius: .4em; -moz-border-radius: .4em; border-radius: .4em;">

<a href="http://www.ro-cazare.info" target="_blank" title="Portal de PROMOVARE online locatii de cazare din Romania" alt="Portal de PROMOVARE online locatii de CAZARE din ROMANIA">
	<img id="footerimg" src="http://www.ro-cazare.info/img/ro-cazare-baner-88x30.jpg">
</a>

<a href="https://plus.google.com/113064483531859929520" target="_blank" rel="author">
	<img id="footerimg" src="http://www.ro-cazare.info/img/ro-cazare-google-plus.jpg">
</a>	
			
<a href="https://www.facebook.com/Promovare.Cazare.Romania" target="_blank">
	<img id="footerimg" src="http://www.ro-cazare.info/img/facebook_logo.jpg">
</a>

<a href="http://www.romaniadevis.ro/dacia/" target="_blank">
	<img id="footerimg" src="http://www.ro-cazare.info/img/romania-de-vis.jpg">
</a>

<a href="http://www.cumpar-vand.info" target="_blank">
	<img id="footerimg" src="http://www.cumpar-vand.info/img/anunturi-gratuite-cumpar-vand.jpg">
</a> 

<a href="http://salvatisatulromanesc.wordpress.com/featured-events-list/" target="_blank">
	<img id="footerimg" src="http://www.ro-cazare.info/img/salvati-satul-romanesc.jpg">
</a> 

<a href="http://www.allgarden.ro" target="_blank">
	<img id="footerimg" src="http://www.allgarden.ro/wp-content/uploads/allgarden-gradini-parcuri-spatii-verzi.jpg">
</a> 

<a href="http://www.inchirieri-utilaj.ro" target="_blank">
	<img id="footerimg" src="http://www.inchirieri-utilaj.ro/wp-content/uploads/2017/03/inchirieri-utilaje-constructii.jpg">
</a> 

<a href="http://www.possesso-cafe.ro" target="_blank">
	<img id="footerimg" src="http://www.possesso-cafe.ro/img/possesso-cafe-cafenea jpg">
</a> 

<br />
Pentru orice nelamurire sau problema nu ezitati sa ne contactati ( <a href="mailto:contact@ro-cazare.info">contact@ro-cazare.info</a> )
	</p>';
?>
<div id="eXTReMe"><a href="http://extremetracking.com/open?login=moshules">
<!--<img src="http://t1.extreme-dm.com/i.gif" style="border: 0;"
height="38" width="41" id="EXim" alt="eXTReMe Tracker" />--></a>
<script type="text/javascript"><!--
EXref="";top.document.referrer?EXref=top.document.referrer:EXref=document.referrer;//-->
</script><script type="text/javascript"><!--
var EXlogin='moshules' // Login
var EXvsrv='s9' // VServer
EXs=screen;EXw=EXs.width;navigator.appName!="Netscape"?
EXb=EXs.colorDepth:EXb=EXs.pixelDepth;EXsrc="src";
navigator.javaEnabled()==1?EXjv="y":EXjv="n";
EXd=document;EXw?"":EXw="na";EXb?"":EXb="na";
EXref?EXref=EXref:EXref=EXd.referrer;
EXd.write("<img "+EXsrc+"=http://e0.extreme-dm.com",
"/"+EXvsrv+".g?login="+EXlogin+"&amp;",
"jv="+EXjv+"&amp;j=y&amp;srw="+EXw+"&amp;srb="+EXb+"&amp;",
"l="+escape(EXref)+" height=1 width=1>");//-->
</script><noscript><div id="neXTReMe"><img height="10" width="10" alt=""
src="http://e0.extreme-dm.com/s9.g?login=moshules&amp;j=n&amp;jv=n" />
</div></noscript></div>