body {
background-color : #f4f4f4;
background : url(img/linie_300x1.jpg) center top repeat-x fixed;
font-family : 'Questrial', sans-serif;
font-size : 14px;
font-weight : 400;
color : #000000;
}
#promovat {
width : 90%;
background-color : #f4f4f4;
color : #000000;
text-align : center;
}
#categorie {
padding : 8px;
font-family : 'Rye', cursive;
font-size : 14px;
color : #D76511;
font-weight : 400;
text-shadow : 1px 1px 1px #c1c1c1;
text-align : left;
background-color : #FCFFC4;
text-indent : 10px;
border : #000000 solid thin;
border-radius : 0.4em;
}
#subcategorie {
padding : 5px;
font-family : Courier;
font-size : 12px;
color : #000000;
text-align : left;
text-indent : 18px;
text-shadow : 1px 1px 1px #c1c1c1;
background-color : #E0FFB3;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#titlujudet {
width : 597px;
padding : 18px;
font-family : 'Rye', cursive;
font-size : 22px;
font-weight : 400;
color : #F06715;
text-shadow : 2px 2px 2px #9D9D9D;
text-align : center;
text-indent : 10px;
}
#titlu {
padding : 18px;
font-family : 'Rye', cursive;
font-size : 22px;
font-weight : 400;
color : #00499B;
text-shadow : 1px 1px 2px #9D9D9D;
text-align : center;
text-indent : 10px;
}
#chenar {
width : 190px;
height : 120px;
padding : 4px;
margin : 5.5px;
float : left;
position : relative;
font-family : 'Rye', cursive;
font-size : 14px;
font-weight : 200;
text-align : left;
background-image : url(/img/dunga_gri.jpg);
border : #ffffff solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}
#denumirelocatie {
height : 30px;
padding : 4px;
font-family : 'Rye', cursive;
font-size : 14px;
font-weight : 200;
text-align : left;
position : relative;
}
#inchenar {
height : 25px;
padding : 4px;
text-indent : 20px;
font-family: 'Questrial', sans-serif;
font-size : 14px;
font-weight : 200;
text-align : left;
position : relative;
}
#butondetalii {
width : 80px;
padding : 4px;
margin-top: 1px;
float : right;
font-family : 'Rye', cursive;
font-size : 12px;
text-align : left;
position : relative;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}
#butondetaliilocatie {
padding : 10px;
float : right;
font-family : 'Rye', cursive;
font-size : 12px;
text-align : left;
text-indent : 0;
margin : 8px;
background : #5CFE89;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}
#fotomica {
width : 110px;
height : 83px;
padding : 4px;
margin : 4px;
border : #000000 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}
#fotomicagalerie {
width : 67px;
height : 50px;
padding : 2px;
margin : 2px;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}
#fotopopup {
width: 600px;
padding: 8px;
position: fixed; 
top: 150px;
left: 25%; 
z-index: 1000;
border: #000000 solid thin;
border-radius : 0.8em;
box-shadow : 10px 10px 100px #000000;
}
#fotopromo {
width : 134px;
height : 101px;
padding : 4px;
margin : 4px;
border : #000000 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}
#fotoconsilier {
width : 140px;
padding : 4px;
margin : 20px;
border : #000000 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 40px #000000;
}
#consilieri {
font-family : 'Verdana', cursive;
font-size : 12px;
text-align : left;
line-height : 2;
}
#bulina {
width : 20px;
}
#campfoto {
width : 100%;
}
#continut {
padding-left : 10px;
font-family : 'Questrial', sans-serif;
font-size : 14px;
text-align : left;
text-indent : 20px;
line-height : 1.2;
}
citat {
padding : 4px;
margin-left: 20px;
font-family : 'Questrial', sans-serif;
font-size : 14px;
text-align : left;
line-height : 1.5;
}
#centru{
padding: 5px;
margin-left: auto; 
margin-right: auto;
}
#gratuit {
background-color : #f4f4f4;
border : #000000 solid thin;
border-radius : 0.4em;
box-shadow : 1px 1px 4px #000000;
}

#tdrotunjit {
width : 33%;
height : 28px;
text-align: center;
text-indent : 10px;
border : #000000 solid thin;
border-radius : 0.4em;
}
#header {
height : 203px;
text-align : center;
vertical-align: middle;
text-shadow : 1px 1px 40px #ffffff;
font-family : 'Rye', cursive;
font-size : 40px;
color : #727272;
background-color : #f4f4f4;
background-image : url(/img/header998x203.png);
border : #c1c1c1 solid thin;
border-radius : 0.2em;
}
#spatiuorizontal {
height : 10px;
text-align : center;
}
#butonmenuoriz {
width : 120px;
height : 38px;
padding : 4px;
float : right;
text-align : center;
margin-left : 2px;
font-family : 'Rye', cursive;
font-size : 11px;
color : #000000;
line-height : 36px;
background-image : url(http://www.ro-cazare.info/img/buton1.png);
}
#menuorizontal {
height : 60px;
}
#facebook {
width : 120px;
height : 38px;
padding : 4px;
float : right;
text-align : center;
margin-left : 2px;
font-family : 'Rye', cursive;
font-size : 11px;
color : #000000;
line-height : 36px;
background-image : url(/img/facebook_logo.jpg);
}
#menulocatie {
width : 12%;
height : 28px;
padding : 4px;
float : left;
text-align : center;
margin-left : 4px;
font-family : verdana;
font-size : 11px;
color : #000000;
background-color : #E0FFB3;
border : #000000 solid thin;
border-radius : 0.4em;
}
#dinamic {
width : 850px;
vertical-align : top;
padding: 10px;
background-color : #f4f4f4;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#coloanadreapta {
width : 200px;
text-align : center;
vertical-align : top;
padding-top: 5px;
background-color : #f4f4f4;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#footer {
text-align : center;
padding: 10px;
background-color : #f4f4f4;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#footerimg{
width:88px; 
height:31px; 
padding: 4px; 
margin: 2px; 
border: #000000 solid thin; 
border-radius: 0.4em; 
box-shadow: 1px 1px 4px #000000;"
}
#judet {
width : 128px;
height : 60px;
margin : 0;
text-align : center;
}
#tableadaugalocatie {
width : 100%;
margin-left : 2px;
vertical-align : top;
font-size : 12px;
color : #000000;
}
#cauta {
width : 120px;
height : 30px;
padding : 0;
text-align : center;
font-family : 'Rye', cursive;
font-size : 11px;
color : #000000;
line-height : 16px;
background-image : url(/img/buton1_.png);
}
#captabel {
padding : 8px;
font-family : 'Rye', cursive;
font-size : 14px;
color : #D76511;
font-weight : 400;
text-shadow : 1px 1px 1px #c1c1c1;
text-align : center;
background-color : #FCFFC4;
border : #000000 solid thin;
border-radius : 0.4em;
}
#continuttabel {
	padding : 8px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	color : #F33232;
	font-weight : 200;
	text-shadow : 1px 1px 1px #c1c1c1;
	text-align : center;
	background-color : #E0FFB3;
	border : #000000 solid thin;
	border-radius : 0.4em;
}
#top {
	padding : 6px;
	float : right;
	font-family : 'Rye', cursive;
	font-size : 12px;
	color : #F33232;
	font-weight : 200;
	text-shadow : 1px 1px 1px #c1c1c1;
	text-align : center;
	background-color : #E0FFB3;
	border : #000000 solid thin;
	border-radius : 0.4em;
}
#cautare {
	text-align : center;
	padding: 10px;
	background-color : #f4f4f4;
	border : #000000 solid thin;
	border-radius : 0.4em;
}
#tdcomentarii1 {
	width : 90px;
	text-indent : 10px;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#tdcomentarii2 {
	width : 510px;
	text-indent : 10px;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#tdcomentarii3 {
	width : 90%;
	background-color: #D5EAFF; 
	margin-top: 10px; 
	margin-bottom: 10px; 
	text-indent: 20px; 
	padding: 10px;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#tdcomentarii4 {
	width : 440px;
	background-color: #D5FFEA; 
	margin: 2px; 
	float: right;
	text-indent: 20px; 
	padding: 10px;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#nota{
	font-family : 'Rye', cursive;
	font-size : 18px;
	font-weight : 200;
	color : red;
	text-align : center;
}
#media{
	width: 60px;
	height: 60px;
	font-family : 'Rye', cursive;
	font-size : 22px;
	font-weight : 200;
	color : red;
	text-align : center;
	padding:30px;
	background: #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#qrcode{
	width: 100px;
	height: 100px;
	font-family : 'Rye', cursive;
	font-size : 22px;
	font-weight : 200;
	color : red;
	text-align : center;
	padding: 10px;

}
#promotie {
	padding : 40px;
	font-family : 'Questrial', sans-serif;
	font-size : 14px;
	text-align : left;
	text-indent : 40px;
	line-height: 1.5;
}

li {
text-indent: 4px;
}
h3 {
font-family : 'Rye', cursive;
color : #F33232;
text-shadow : 1px 1px 2px #9D9D9D;
font-weight : 300;
}
input {
padding : 4px;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
textarea {
padding : 4px;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
select {
padding : 4px;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#selectcautare{
width: 180px;
padding : 4px;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}

#fieldsethome {
	width : 222px;
	height: 150px;
	float: left;
	padding : 8px;
	margin-top : 7px;
	margin-right : 4px;
	line-height : 14px;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legendhome {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	color: #00499B;
	background-color : #ECF5FF;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetcontinut {
	width : 730px;
	padding : 20px;
	margin-top : 17px;
	line-height : 1.4;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetcontinut1 {
	width : 342px;
	height: 180px;
	padding : 20px;
	float: left;
	margin-top : 17px;
	margin-bottom: 17px;
	line-height : 1.4;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legendcontinut{
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	color : #00499B;
	background-color : #ECF5FF;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetlocatie {
	width : 700px;
	height: 1000px;
	padding : 12px;
	margin-top : 6px;
	line-height : 14px;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legendlocatie {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	background-color : #ECF5FF;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetdreaptapromo {
	width : 156px;
	height : 280px;
	vertical-align : top;
	padding : 8px;
	margin-top : 10px;
	line-height : 16px;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legenddreaptapromo {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	background-color : #ECF5FF;  
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
} 
#fieldsetdreapta {
	width : 156px;
	padding : 8px;
	margin-top : 10px;
	line-height : 16px;
	color : #000000;
	text-align : left;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legenddreapta {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	color: blue;
	background-color : #ECF5FF;  
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#fieldsetcautare{
	width : 96%;
	margin-top: 10px;
	margin-bottom: 10px;
	margin-left : auto;
	margin-right : auto;
	vertical-align : top;
	padding : 10px;
	line-height : 16px;
	color : #000000;
	text-align : center;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legendcautare {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 10px;
	padding-bottom : 10px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 12px;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#rezervheader{
	width: 1000px; 
	height: 205px; 
	position: fixed; 
	top: 9px; 
	left: 50%; 
	margin: 0 0 0 -501px;
	padding: 5px;
	background-color : #5CFE89;
	background: filter:alpha(opacity=95); -moz-opacity: 0.95;	opacity: 0.95;
	border : #000000 solid thin;
	border-radius : 0.4em;
}
#fieldsetrezerv{
	width : 716px;
	height : 165px;
	vertical-align : top;
	padding-top : 10px;
	padding-left : 10px;
	line-height : 8px;
	color : #000000;
	text-align : left;
	background-color : #E0FFB3;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#legendrezerv {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 10px;
	padding-bottom : 10px;
	margin-left : 1px;
	margin-right : 12px;
	font-family : 'Rye', cursive;
	font-size : 14px;
	background-color : #ECF5FF;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#selectcautare1{
width: 180px;
padding : 4px;
margin: 2px;
background-color : #F8FFEC;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#textarea1{
width: 168px;
height: 76px;
padding : 4px;
margin: 2px;
background-color : #F8FFEC;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#selectcautare1cod{
width: 20px;
padding : 4px;
margin: 2px;
background-color : #F8FFEC;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#rezervare_submit{
width: 117px;
height: 117px;
padding : 8px;
font-family : 'Rye', cursive;
color : #000000;
background-color : #F4F4F4;
border : #c1c1c1 solid thin;
border-radius : 0.4em;
}
#submit {
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin-left : 1px;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#submitadresa {
	width: 90%;
	padding-left : 10px;
	padding-right : 10px;
	padding-top : 5px;
	padding-bottom : 5px;
	margin: 10px;
	background-color : #ffffff;
	border : #c1c1c1 solid thin;
	border-radius : 0.4em;
}
#submit a:visited {
text-decoration : none;
font-family : 'Rye', cursive;
font-size : 19px;
font-weight : 400;
color : #000000;
}
#submit a:hover {
text-decoration : none;
font-family : 'Rye', cursive;
font-size : 19px;
font-weight : 400;
color : green;
}
#submit a:active {
text-decoration : none;
font-family : 'Rye', cursive;
font-size : 19px;
font-weight : 400;
color : #000000;
}
a:link {
text-decoration : none;
font-size : 12px;
color : #000000;
}
a:visited {
text-decoration : none;
font-size : 12px;
color : #000000;
}
a:hover {
color : #000000;
font-size : 12px;
}
a:active {
text-decoration : none;
font-size : 12px;
color : #000000;
}